;---------------------------------------------------------------------------
; Sample AutoHotkey script which displays an option screen to allow the user
; to select different photobooth profiles. Optionally hide the mouse cursor
; using the free 'nomousy' utility.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; nomousy is free and can be downloaded from:
; http://www.apps4apps.filetap.com/nomousy.html
;
;
; This script works with:
; DSLR Remote Pro for Windows v1.9.1 or later
; NKRemote v1.4 or later
; PSRemote v1.9 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;---------------------------------------------------------------------------
#SingleInstance force

; set this to 1 to hide the cursor when the options screen is displayed
HideCursor = 0

; define the options screen
Gui, Color, 0
Gui, -Caption -Border +AlwaysOnTop
Gui, Font, s48, Arial
; Gui, Add, Picture,,C:\Photobooth\PhotoboothImages\4.jpg	; uncomment this line to use a background image
Gui, Add, Text, x0 y0 cWhite gStartClicked, Use current settings
Gui, Add, Text, cWhite gProfile1Clicked, Select profile 1
Gui, Add, Text, cWhite gProfile2Clicked, Select profile 2
Gui, Font, norm

; loop forever monitoring the status of the photobooth screen
Ready = 0	; 0 tells script to display options screen if ready.jpg screen is displayed
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains ready.jpg
		{
			if Ready = 0
			{
				Ready = 1
				ShowOverlayWindow()
			}
		}
		else if Title contains processing.jpg
		{
			Ready = 0	; start looking for ready.jpg screen
		}
	}
	else
	{
		Ready = 0
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

GuiEscape:
HideOverlayWindow(0)
return

; Ctlr+Q shows the options screen if ready.jpg is being displayed
^q::
Ready = 0
return

; Hide the options screen
StartClicked:
HideOverlayWindow(0)
return

; Send Shift+Ctrl+1 to photobooth to select profile 1 and then hide the options screen
Profile1Clicked:
WinActivate, Breeze Systems Photobooth
Send +^1
HideOverlayWindow(250)	; give the photobooth time to switch profiles before hiding the options screen
return

; Send Shift+Ctrl+2 to photobooth to select profile 2 and then hide the options screen
Profile2Clicked:
WinActivate, Breeze Systems Photobooth
Send +^2
HideOverlayWindow(250)	; give the photobooth time to switch profiles before hiding the options screen
return

; show the overlay window and optionally hide the mouse cursor
ShowOverlayWindow()
{
	global HideCursor
	Gui, Show, Maximize
	if HideCursor > 0
	{
		Run, nomousy.exe /hide
	}
}

; hide the overlay window with optional delay
HideOverlayWindow(delay)
{
	global HideCursor
	WinActivate, Breeze Systems Photobooth
	if delay > 0
	{
		Sleep delay
	}
	Gui, Hide
	if HideCursor > 0
	{
		Run, nomousy.exe
	}
}
