;---------------------------------------------------------------------------
; Sample AutoHotkey script which displays a window on top of the
; photobooth window to hide the live view display while photos are
; being printed.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; nomousy is free and can be downloaded from:
; http://www.apps4apps.filetap.com/nomousy.html
;
; This script works with:
; DSLR Remote Pro for Windows v1.9.1 or later
; NKRemote v1.4 or later
; PSRemote v1.9 or later
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;---------------------------------------------------------------------------
#SingleInstance force

UseNomousyToHideCursor = 1

; create an "always on top" black window with no title bar
Gui, Color, cBlue
Gui, -Caption -Border +AlwaysOnTop
Gui, Font, s36, Arial
Gui, Add, Text, cWhite x200 y200, Thank You!
Gui, Add, Text, cWhite, Your photos are being printed outside
Gui, Add, Text, cWhite, Please leave the booth now
Gui, Font, norm

; loop forever monitoring the status of the photobooth screen
Processing = 0	; 0 tells script to display processing overlay if processing.jpg screen is displayed
Loop
{
	IfWinExist, Breeze Systems Photobooth
	{
		WinGetTitle, Title, Breeze Systems Photobooth
		if Title contains processing.jpg
		{
			if Processing = 0
			{
				Processing = 1
				ShowOverlayWindow()
			}
		}
		else if Title contains ready.jpg
		{
			if Processing <> 0
			{
				; hide overlay and start looking for processing.jpg screen
				HideOverlayWindow()
				Processing = 0
			}
		}
	}
	else
	{
		Processing = 0
	}
	Sleep 100	; sleep for 1/10th sec to avoid hogging the processor
}
Return

GuiEscape:
HideOverlayWindow()
return

; show the overlay window and optionally hide the mouse cursor
ShowOverlayWindow()
{
	global UseNomousyToHideCursor
	Gui, Show, Maximize
	if UseNomousyToHideCursor > 0
	{
		Run, nomousy.exe /hide
	}
}

; hide the overlay window and restore the mouse cursor
HideOverlayWindow()
{
	global UseNomousyToHideCursor
	WinActivate, Breeze Systems Photobooth
	Gui, Hide
	if UseNomousyToHideCursor > 0
	{
		Run, nomousy.exe
	}
}
