;-----------------------------------------------------------------------
; Sample AutoHotkey script shows how to remap the keyboard shortcuts
; 
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; This script should work with all versions of DSLR Remote Pro for Windows,
; NKRemote and PSRemote
;
; This script comes with no warranty or support whatsoever and may
; be freely copied or modified as required.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------
#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#SingleInstance force
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
SetTitleMatchMode,2

; define keyboard macros for when the full screen photobooth window is displayed
#IfWinExist, Breeze Systems Photobooth

; Use the space bar to send Ctrl+Z to take photo in clicker mode
Space::
WinActivate,Breeze Systems Photobooth
Send ^z
return

; ignore Numpad +/- and Ctrl+3 to Ctrl+9 for selecting the number of copies - this
; will only allow the user to select one or two copies
NumpadAdd::
NumpadSub::
^3::
^4::
^5::
^6::
^7::
^8::
^9::
return
 
; Remap wireless presenter keys e.g. Kensington wireless presenters generate the following key presses:
; top/laser button -> F5, start the shooting sequence (some models don't generate a key press)
F5::ControlSend,,{F4},Breeze Systems Photobooth

; previous/left -> PageUp, reduce the number of copied to print
PgUp::ControlSend,,{NumpadSub},Breeze Systems Photobooth

; next/right -> PageDown, increase the number of copies to print
PgDn::ControlSend,,{NumpadAdd},Breeze Systems Photobooth

; stop/bottom -> b, reprint
b::ControlSend,,^r,Breeze Systems Photobooth

; 1 selects one copy, 2 selects two copies
1::ControlSend,,^1,Breeze Systems Photobooth
2::ControlSend,,^2,Breeze Systems Photobooth

; Win+Tab resets the booth to color and one copy
#Tab::ControlSend,,^1^c,Breeze Systems Photobooth

; Prevent Esc from exiting photobooth mode
Esc::
return

; Use Shift+Ctrl+Esc to exit photobooth mode
+^Esc::ControlSend,,{Esc},Breeze Systems Photobooth

; Tab key makes the full screen photobooth window the active window
Tab::WinActivate, Breeze Systems Photobooth

#IfWinExist

; Define any global keyboard macros here

; Win+Tab starts full screen photobooth mode if DSLR Remote Pro, NKRemote or PSRemote is running
#Tab::
IfWinExist, DSLR Remote Pro for Windows - Connected
{
	WinActivate, DSLR Remote Pro for Windows - Connected
	Send ^{F4}
}
else IfWinExist, PSRemote - Connected
{
	WinActivate, PSRemote - Connected
	Send ^{F4}
}
else IfWinExist, NKRemote - Connected
{
	WinActivate, NKRemote - Connected
	Send ^{F4}
}
return
